@@ -179,7 +179,7 @@ class Connection(object):
     def getColumns(self, database, table):
         return self.get_columns(database, table)
 
-    def get_schema_names(self, database, table):
+    def get_schema_names(self):
         return self._client.getSchemaNames()
 
     def commit(self):
